import { components } from '@octokit/openapi-types';
import BetterSSE from 'better-sse';
import { IncomingMessage, ServerResponse } from 'http';
import { Context } from 'koa';
import { Repository } from './index.js';
export type HookEvent = components['schemas']['hook-delivery-item'] & {
    id: number;
    signature: string;
    repository?: Repository;
    issue?: components['schemas']['issue'];
};
export type EventFilter = Partial<Record<'owner' | 'repository' | 'event', string>>;
export declare class HookController {
    channel: BetterSSE.Channel<{}, Partial<Record<"repository" | "owner" | "event", string>>>;
    bootSSE(request: IncomingMessage, response: ServerResponse, state: EventFilter): Promise<void>;
    /**
     * @param  name       `X-GitHub-Event`: Event name
     * @param  id         `X-GitHub-Delivery`: Unique ID for this delivery
     * @param  signature  `X-Hub-Signature`: HMAC hex digest of the payload
     *
     * @see {@link https://docs.github.com/webhooks/webhook-events-and-payloads#delivery-headers}
     */
    emitEvent(name: string | undefined, id: number | undefined, signature: string | undefined, event: HookEvent): void;
    getOrgEvent(owner: string, request: IncomingMessage, response: ServerResponse, { req, res }?: Context): Promise<void>;
    getRepoEvent(owner: string, repository: string, request: IncomingMessage, response: ServerResponse, { req, res }?: Context): Promise<void>;
    getIssueEvent(owner: string, repository: string, request: IncomingMessage, response: ServerResponse, { req, res }?: Context): Promise<void>;
}
