import { __decorate, __metadata, __param } from "tslib";
import { IsInt, IsString, Min } from 'class-validator';
import { Get, HeaderParam, JsonController, Param } from 'routing-controllers';
import { OpenAPI, ResponseSchema } from 'routing-controllers-openapi';
import { githubAPIClient } from './OAuth.js';
function countTech(list) {
    const tech = {};
    for (let item of list)
        for (let name in item) {
            tech[name] ||= { name, count: 0 };
            tech[name].count += item[name];
        }
    return Object.values(tech).sort((A, B) => B.count - A.count);
}
async function filterRepository(path, header) {
    const { body } = await githubAPIClient.get(path, header);
    const languages = await Promise.all(body
        .filter(({ fork, permissions }) => !fork && (!header?.['Authorization'] || permissions?.push))
        .map(async ({ languages_url }) => {
        const { body } = await githubAPIClient.get(languages_url, header);
        return body;
    }));
    return countTech(languages);
}
/**
 * Technique/Language meta
 */
export class Language {
    name = '';
    count = 0;
}
__decorate([
    IsString(),
    __metadata("design:type", String)
], Language.prototype, "name", void 0);
__decorate([
    IsInt(),
    Min(0),
    __metadata("design:type", Number)
], Language.prototype, "count", void 0);
let LanguageController = class LanguageController {
    getUserLanguages(name, Authorization = '') {
        return filterRepository(`users/${name}/repos?type=all`, {
            Authorization
        });
    }
    async getOAuthUserLanguages(Authorization = '') {
        return filterRepository('user/repos?affiliation=owner,collaborator', {
            Authorization
        });
    }
    getOrganizationLanguages(name = '', Authorization = '') {
        return filterRepository(`orgs/${name}/repos`, { Authorization });
    }
};
__decorate([
    OpenAPI({
        description: 'Get Technique(Language)s of a User'
    }),
    Get('/users/:name/languages'),
    ResponseSchema(Language, { isArray: true }),
    __param(0, Param('name')),
    __param(1, HeaderParam('Authorization')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Object]),
    __metadata("design:returntype", void 0)
], LanguageController.prototype, "getUserLanguages", null);
__decorate([
    OpenAPI({
        description: 'Get Technique(Language)s of an OAuth User'
    }),
    Get('/user/languages'),
    ResponseSchema(Language, { isArray: true }),
    __param(0, HeaderParam('Authorization')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], LanguageController.prototype, "getOAuthUserLanguages", null);
__decorate([
    OpenAPI({
        description: 'Get Technique(Language)s of an Organization'
    }),
    Get('/orgs/:name/languages'),
    ResponseSchema(Language, { isArray: true }),
    __param(0, Param('name')),
    __param(1, HeaderParam('Authorization')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object]),
    __metadata("design:returntype", void 0)
], LanguageController.prototype, "getOrganizationLanguages", null);
LanguageController = __decorate([
    JsonController()
], LanguageController);
export { LanguageController };
//# sourceMappingURL=Language.js.map