import { __decorate, __metadata, __param } from "tslib";
import KoAJAX from 'koajax';
import { Get, HeaderParam, JsonController, QueryParam, Redirect, Req, Res } from 'routing-controllers';
import { OpenAPI } from 'routing-controllers-openapi';
const setUserAgent = ({ request }, next) => {
    request.headers = {
        'user-agent': process.env.HTTP_USER_AGENT || 'GitHub RESTful middleware',
        ...request.headers
    };
    return next();
};
export const githubClient = new KoAJAX.HTTPClient({
    baseURI: 'https://github.com/',
    responseType: 'json'
}).use(setUserAgent);
export const githubAPIClient = new KoAJAX.HTTPClient({
    baseURI: 'https://api.github.com/',
    responseType: 'json'
}).use(setUserAgent);
let OauthController = class OauthController {
    /**
     * @param referer - Referer URL of Source Page
     */
    goToSignInPage(referer = '') {
        const { GITHUB_OAUTH_CLIENT_ID = '', GITHUB_OAUTH_SCOPE = '' } = process.env;
        return `${githubClient.baseURI}login/oauth/authorize?${new URLSearchParams({
            client_id: GITHUB_OAUTH_CLIENT_ID,
            scope: GITHUB_OAUTH_SCOPE,
            state: Buffer.from(referer).toString('base64')
        })}`;
    }
    /**
     * @param  code   Disposable checksum
     * @param  state  Last Page Referer of this site in Base64
     */
    async backToRefererPage(state = '', code = '', request, response) {
        const { GITHUB_OAUTH_CLIENT_ID = '', GITHUB_OAUTH_CLIENT_SECRET = '' } = process.env;
        //  Local Debug
        const refererURL = new URL(Buffer.from(state, 'base64') + '');
        const { hostname, protocol, host } = refererURL;
        if (hostname === 'localhost' && request.hostname !== 'localhost')
            return response.redirect(`${protocol}//${host + request.originalUrl}`);
        /**
         * @see {@link https://developer.github.com/v3/users/#get-the-authenticated-user|More data about the Login User}
         */
        const { body } = await githubClient.post('login/oauth/access_token', {
            client_id: GITHUB_OAUTH_CLIENT_ID,
            client_secret: GITHUB_OAUTH_CLIENT_SECRET,
            code
        });
        refererURL.searchParams.set('access_token', body?.access_token || '');
        response.redirect(refererURL + '');
    }
};
__decorate([
    OpenAPI({ description: 'Redirect to OAuth Page of GitHub' }),
    Get(),
    Redirect(`${githubClient.baseURI}login/oauth/authorize`),
    __param(0, HeaderParam('Referer')),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], OauthController.prototype, "goToSignInPage", null);
__decorate([
    OpenAPI({ description: 'OAuth Callback for GitHub' }),
    Get('/callback'),
    __param(0, QueryParam('state')),
    __param(1, QueryParam('code')),
    __param(2, Req()),
    __param(3, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, Object, Object, Object]),
    __metadata("design:returntype", Promise)
], OauthController.prototype, "backToRefererPage", null);
OauthController = __decorate([
    JsonController('/OAuth')
], OauthController);
export { OauthController };
//# sourceMappingURL=OAuth.js.map