import { __decorate, __metadata, __param } from "tslib";
import { isNotEmptyObject } from 'class-validator';
import { html } from 'diff2html';
import { All, Body, Controller, Get, HeaderParam, Param, Req, Res } from 'routing-controllers';
import { githubAPIClient, githubClient } from './OAuth.js';
let ProxyController = class ProxyController {
    /**
     * @param  owner          ID of a User or Organization
     * @param  repo           Name of a Repository
     * @param  id             ID of a Pull Request
     * @param  Authorization  Authorization header
     * @param  Accept         Accept header
     * @param  response
     *
     * @example
     * HTML converted from Diff by Diff2HTML
     * ```html
     * <div class="d2h-wrapper"></div>
     * ```
     */
    async getDiffFile(owner, repo, id, Authorization = '', Accept = '', response) {
        const { body } = await githubClient.get(`${owner}/${repo}/pull/${id}.diff`, { Authorization }, { responseType: 'text' });
        const acceptHTML = Accept.includes('html');
        response.set('Content-Type', acceptHTML ? 'text/html' : 'text/plain');
        return acceptHTML
            ? html(body, { outputFormat: 'side-by-side' })
            : body;
    }
    /**
     * Other API Proxy
     */
    async proxyAll(accept = '', path, body, request, response) {
        const acceptJSON = accept.includes('json'), { host, connection, ...header } = request.headers;
        const res = await githubAPIClient.request({
            method: request.method,
            path,
            // @ts-ignore
            headers: { ...header, accept },
            body: isNotEmptyObject(body) ? body : undefined,
            responseType: acceptJSON ? 'json' : 'arraybuffer'
        });
        const { status, body: data } = res, { 'Content-Encoding': _, 'Transfer-Encoding': __, ...headers } = res.headers;
        for (const key in headers)
            if (key === 'Link') {
                const value = Object.values(headers[key]).map(({ URI, ...meta }) => {
                    const value = Object.entries(meta).map(([key, value]) => `${key}=${JSON.stringify(value)}`);
                    return `<${URI}>; ${value.join('; ')}`;
                });
                headers[key] = value.join(', ');
            }
        if (typeof response.status === 'function')
            response.status(status);
        else
            response.status = status;
        response.set(headers);
        return data;
    }
};
__decorate([
    Get('/repos/:owner/:repo/pull/:id.diff'),
    __param(0, Param('owner')),
    __param(1, Param('repo')),
    __param(2, Param('id')),
    __param(3, HeaderParam('Authorization')),
    __param(4, HeaderParam('Accept')),
    __param(5, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, String, Number, Object, Object, Object]),
    __metadata("design:returntype", Promise)
], ProxyController.prototype, "getDiffFile", null);
__decorate([
    All('/:path*'),
    __param(0, HeaderParam('Accept')),
    __param(1, Param('path')),
    __param(2, Body()),
    __param(3, Req()),
    __param(4, Res()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, String, Object, Object, Object]),
    __metadata("design:returntype", Promise)
], ProxyController.prototype, "proxyAll", null);
ProxyController = __decorate([
    Controller()
], ProxyController);
export { ProxyController };
//# sourceMappingURL=Proxy.js.map